<?php
// De-register Contact Form 7 styles.
add_filter( 'wpcf7_load_js', '__return_false' );
add_filter( 'wpcf7_load_css', '__return_false' );

// Main Styles.
function thb_main_styles() {
	global $post;

	$i                       = 0;
	$self_hosted_fonts       = ot_get_option( 'self_hosted_fonts' );
	$thb_theme_directory_uri = Thb_Theme_Admin::$thb_theme_directory_uri;
	$thb_theme_version       = Thb_Theme_Admin::$thb_theme_version;

	// Enqueue.
	wp_enqueue_style( 'thb-fa', esc_url( $thb_theme_directory_uri ) . 'assets/css/font-awesome.min.css', null, esc_attr( $thb_theme_version ) );
	wp_enqueue_style( 'thb-app', esc_url( $thb_theme_directory_uri ) . 'assets/css/app.css', null, esc_attr( $thb_theme_version ) );

	wp_dequeue_style( 'vc_lte_ie9' );
	wp_deregister_style( 'vc_lte_ie9' );

	if ( ! defined( 'THB_DEMO_SITE' ) ) {
		wp_enqueue_style( 'thb-style', get_stylesheet_uri(), null, esc_attr( $thb_theme_version ) );
	}
	wp_enqueue_style( 'thb-google-fonts', thb_google_webfont(), null, esc_attr( $thb_theme_version ) );
	wp_add_inline_style( 'thb-app', thb_selection() );

	if ( $self_hosted_fonts ) {
		foreach ( $self_hosted_fonts as $font ) {
			$i++;
			wp_enqueue_style( 'thb-self-hosted-' . $i, $font['font_url'], null, esc_attr( $thb_theme_version ) );
		}
	}

	if ( $post ) {
		if ( has_shortcode( $post->post_content, 'contact-form-7' ) && function_exists( 'wpcf7_enqueue_styles' ) ) {
			wpcf7_enqueue_styles();
		}
	}
	// Remove Dynamic front-end CSS.
	remove_action( 'wp_enqueue_scripts', 'ot_load_dynamic_css', 999 );
}
add_action( 'wp_enqueue_scripts', 'thb_main_styles' );

// Main Scripts.
function thb_register_js() {
	if ( ! is_admin() ) {
		global $post;

		$thb_combined_libraries  = ot_get_option( 'thb_combined_libraries', 'on' );
		$thb_api_key             = ot_get_option( 'map_api_key' );
		$thb_dependency          = array( 'jquery', 'underscore' );
		$thb_theme_directory_uri = Thb_Theme_Admin::$thb_theme_directory_uri;
		$thb_theme_version       = Thb_Theme_Admin::$thb_theme_version;

		// Register.
		if ( 'on' === $thb_combined_libraries ) {
			wp_enqueue_script( 'thb-vendor', esc_url( $thb_theme_directory_uri ) . 'assets/js/vendor.min.js', array( 'jquery' ), esc_attr( $thb_theme_version ), true );
			$thb_dependency[] = 'thb-vendor';
		} else {
			$thb_js_libraries = array(
				'GSAP'                 => '_0gsap.min.js',
				'GSAP-DrawSVGPlugin'   => '_1DrawSVGPlugin.min.js',
				'GSAP-SplitText'       => '_1SplitText.min.js',
				'GSAP-ScrollToPlugin'  => '_2ScrollToPlugin.min.js',
				'animsition'           => 'animsition.js',
				'bezier-easing'        => 'bezier-easing.js',
				'flickity'             => 'flickity.pkgd.min.js',
				'imagesloaded'         => 'imagesloaded.pkgd.min.js',
				'isInViewport'         => 'isInViewport.min.js',
				'isotope'              => 'isotope.pkgd.min.js',
				'jarallax'             => 'jarallax.min.js',
				'isotope-packery-mode' => 'packery-mode.pkgd.js',
				'jquery-hoverIntent'   => 'jquery.hoverIntent.js',
				'magnific-popup'       => 'jquery.magnific-popup.min.js',
				'video'                => 'jquery.vide.js',
				'js-cookie'            => 'js.cookie.js',
				'lazysizes'            => 'lazysizes.min.js',
				'mobile-detect'        => 'mobile-detect.min.js',
				'odometer'             => 'odometer.min.js',
				'perfect-scrollbar'    => 'perfect-scrollbar.min.js',
				'PreventGhostClick'    => 'PreventGhostClick.js',
				'raf'                  => 'raf.js',
				'scrollspy'            => 'scrollspy.js',
				'slick'                => 'slick.min.js',
				'sticky-kit'           => 'sticky-kit.min.js',
				'swiper'               => 'swiper.min.js',
				'thb-3dImg'            => 'thb_3dImg.js',
				'typed'                => 'typed.min.js',
				'howler'               => 'Zhowler.core.min.js',
			);
			foreach ( $thb_js_libraries as $handle => $value ) {
				wp_enqueue_script( $handle, esc_url( $thb_theme_directory_uri ) . 'assets/js/vendor/' . esc_attr( $value ), array( 'jquery' ), esc_attr( $thb_theme_version ), true );
			}
		}
		if ( is_page_template( 'template-fullscreen.php' ) || is_page_template( 'template-onepage.php' ) ) {
			wp_enqueue_script( 'thb-fullscreen', esc_url( $thb_theme_directory_uri ) . 'assets/js/fullscreen.min.js', array( 'jquery', 'thb-vendor' ), esc_attr( $thb_theme_version ), true );
			$thb_dependency[] = 'thb-fullscreen';
		}

		wp_enqueue_script( 'underscore' );
		wp_enqueue_script( 'thb-app', esc_url( $thb_theme_directory_uri ) . 'assets/js/app.min.js', $thb_dependency, esc_attr( $thb_theme_version ), true );

		if ( is_singular() && comments_open() && ( get_option( 'thread_comments' ) ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		if ( $post ) {
			if ( has_shortcode( $post->post_content, 'thb_map_parent' ) ) {
				wp_enqueue_script( 'gmapdep', 'https://maps.google.com/maps/api/js?key=' . esc_attr( $thb_api_key ), false, esc_attr( $thb_theme_version ), false );
			}

			if ( has_shortcode( $post->post_content, 'contact-form-7' ) && function_exists( 'wpcf7_enqueue_scripts' ) ) {
				wpcf7_enqueue_scripts();
			}
		}
		// Typekit.
		$typekit_id = ot_get_option( 'typekit_id' );

		if ( $typekit_id ) {
			wp_enqueue_script( 'thb-typekit', 'https://use.typekit.net/' . $typekit_id . '.js', false, esc_attr( $thb_theme_version ), false );
			wp_add_inline_script( 'thb-typekit', 'try{Typekit.load({ async: true });}catch(e){}' );
		}

		wp_localize_script( 'thb-app', 'themeajax', array(
			'url'  => admin_url( 'admin-ajax.php' ),
			'l10n' => array (
				'of'               => esc_html__( '%curr% of %total%', 'werkstatt' ),
				'loading'          => esc_html__( 'Loading ...', 'werkstatt' ),
				'lightbox_loading' => esc_html__( 'Loading...', 'werkstatt' ),
				'nomore'           => esc_html__( 'No More Posts', 'werkstatt' ),
				'nomore_products'  => esc_html__( 'All Products Loaded', 'werkstatt' ),
				'loadmore'         => esc_html__( 'Load More', 'werkstatt' ),
				'added'            => esc_html__( 'Added To Cart', 'werkstatt' ),
				'added_svg'        => thb_load_template_part( 'assets/svg/arrows_check.svg' ),
				'prev_arrow_key'   => esc_html__( 'Previous (Left arrow key)', 'werkstatt' ),
				'next_arrow_key'   => esc_html__( 'Next (Right arrow key)', 'werkstatt' ),
				'lightbox_close'   => esc_html__( 'Close (Esc)', 'werkstatt' ),
				'adding_to_cart'   => esc_html__( 'Adding to Cart', 'werkstatt' ),
			),
			'svg' => array(
				'prev_arrow' => thb_load_template_part( 'assets/img/svg/prev_arrow.svg' ),
			),
			'settings' => array(
				'current_url'                     => get_permalink(),
				'portfolio_title_animation'       => ot_get_option( 'portfolio_title_animation', 'on' ),
				'page_transition'                 => ot_get_option( 'page_transition', 'on' ),
				'page_transition_style'           => ot_get_option( 'page_transition_style', 'thb-fade' ),
				'page_transition_in_speed'        => ot_get_option( 'page_transition_in_speed', 1000),
				'page_transition_out_speed'       => ot_get_option( 'page_transition_out_speed', 500),
				'shop_product_listing_pagination' => ot_get_option( 'shop_product_listing_pagination', 'style1' ),
				'right_click'                     => ot_get_option( 'right_click', 'on' ),
				'mobile_menu_speed'               => ot_get_option( 'mobile_menu_speed', '0.5' ),
			),
			'sounds' => array(
				'music_sound'                => ot_get_option( 'music_sound', 'off' ),
				'music_sound_toggle_home'    => ot_get_option( 'music_sound_toggle_home', 'off' ),
				'music_sound_file'           => ot_get_option( 'music_sound', 'off' ) === 'on' ? ot_get_option( 'music_sound_file', esc_url( $thb_theme_directory_uri ) . 'assets/sounds/music_sound.mp3' ) : false,
				'menu_item_hover_sound'      => ot_get_option( 'menu_item_hover_sound', 'off' ),
				'menu_item_hover_sound_file' => ot_get_option( 'menu_item_hover_sound', 'off' ) === 'on' ? ot_get_option( 'menu_item_hover_sound_file', esc_url( $thb_theme_directory_uri ) . 'assets/sounds/hover.mp3' ) : false,
				'menu_open_sound'            => ot_get_option( 'menu_open_sound', 'off' ),
				'menu_open_sound_file'       => ot_get_option( 'menu_open_sound', 'off' ) === 'on' ? ot_get_option( 'menu_open_sound_file', esc_url( $thb_theme_directory_uri ) . 'assets/sounds/open.mp3' ) : false,
				'menu_close_sound'           => ot_get_option( 'menu_close_sound', 'off' ),
				'menu_close_sound_file'      => ot_get_option( 'menu_close_sound', 'off' ) === 'on' ? ot_get_option( 'menu_close_sound_file', esc_url( $thb_theme_directory_uri ) . 'assets/sounds/close.mp3' ) : false,
				'click_sound'                => ot_get_option( 'click_sound', 'off' ),
				'click_sound_file'           => ot_get_option( 'click_sound', 'off' ) === 'on' ? ot_get_option( 'click_sound_file', esc_url( $thb_theme_directory_uri ) . 'assets/sounds/click.mp3' ) : false,
			),
		) );
	}
}
add_action( 'wp_enqueue_scripts', 'thb_register_js' );

// WooCommerce.
function thb_woocommerce_scripts_styles() {
	if ( ! is_admin() ) {
		if ( thb_wc_supported() ) {
			wp_dequeue_style( 'woocomimerce_prettyPhoto_css' );
			wp_deregister_style( 'woocommerce_prettyPhoto_css' );

			wp_dequeue_style( 'yith-wcwl-font-awesome' );
			wp_deregister_style( 'yith-wcwl-font-awesome' );

			wp_dequeue_script( 'prettyPhoto' );
			wp_dequeue_script( 'prettyPhoto-init' );

			wp_dequeue_style( 'jquery-selectBox' );
			wp_dequeue_script( 'jquery-selectBox' );

			wp_dequeue_script( 'vc_woocommerce-add-to-cart-js' );
			if ( ! is_checkout() ) {
				wp_dequeue_script( 'jquery-selectBox' );
				wp_dequeue_style( 'selectWoo' );
				wp_dequeue_script( 'selectWoo' );
			}
		}
	}
}

add_action( 'wp_enqueue_scripts', 'thb_woocommerce_scripts_styles', 98 );
add_filter( 'woocommerce_enqueue_styles', '__return_false' );
